@@ -5,7 +5,7 @@ import os
 from collections import namedtuple
 from collections.abc import MutableMapping, MutableSequence
 from io import StringIO
-from typing import Any, IO, Optional, Union, cast
+from typing import IO, Any, Optional, Union, cast
 from urllib.parse import urldefrag
 
 from schema_salad.exceptions import ValidationException
@@ -13,7 +13,7 @@ from schema_salad.sourceline import SourceLine, add_lc_filename
 from schema_salad.utils import aslist, json_dumps, yaml_no_ts
 
 import cwl_utils.parser
-import cwl_utils.parser.cwl_v1_1 as cwl
+import cwl_utils.parser.cwl_v1_0 as cwl
 import cwl_utils.parser.utils
 from cwl_utils.errors import WorkflowException
 from cwl_utils.utils import yaml_dumps
@@ -214,7 +214,7 @@ def check_all_types(
             for src in srcs_of_sink:
                 check_result = check_types(
                     type_dict[cast(str, src.id)],
-                    type_dict[cast(str, sink.id)],
+                    type_dict[sink.id],
                     linkMerge,
                     getattr(sink, "valueFrom", None),
                 )
@@ -272,7 +272,7 @@ def content_limit_respected_read(f: IO[bytes]) -> str:
 
 
 def convert_stdstreams_to_files(clt: cwl.CommandLineTool) -> None:
-    """Convert stdin, stdout and stderr type shortcuts to files."""
+    """Convert stdout and stderr type shortcuts to files."""
     for out in clt.outputs:
         if out.type_ == "stdout":
             if out.outputBinding is not None:
@@ -300,22 +300,6 @@ def convert_stdstreams_to_files(clt: cwl.CommandLineTool) -> None:
                 )
             out.type_ = "File"
             out.outputBinding = cwl.CommandOutputBinding(glob=clt.stderr)
-    for inp in clt.inputs:
-        if inp.type_ == "stdin":
-            if inp.inputBinding is not None:
-                raise ValidationException(
-                    "Not allowed to specify unputBinding when using stdin shortcut."
-                )
-            if clt.stdin is not None:
-                raise ValidationException(
-                    "Not allowed to specify stdin path when using stdin type shortcut."
-                )
-            else:
-                clt.stdin = (
-                    "$(inputs.%s.path)"
-                    % cast(str, inp.id).rpartition("#")[2].split("/")[-1]
-                )
-                inp.type_ = "File"
 
 
 def load_inputfile(
@@ -323,7 +307,7 @@ def load_inputfile(
     baseuri: Optional[str] = None,
     loadingOptions: Optional[cwl.LoadingOptions] = None,
 ) -> Any:
-    """Load a CWL v1.1 input file from a serialized YAML string or a YAML object."""
+    """Load a CWL v1.0 input file from a serialized YAML string or a YAML object."""
     if baseuri is None:
         baseuri = cwl.file_uri(os.getcwd()) + "/"
     if loadingOptions is None:
@@ -342,7 +326,7 @@ def load_inputfile_by_string(
     uri: str,
     loadingOptions: Optional[cwl.LoadingOptions] = None,
 ) -> Any:
-    """Load a CWL v1.1 input file from a serialized YAML string."""
+    """Load a CWL v1.0 input file from a serialized YAML string."""
     yaml = yaml_no_ts()
     result = yaml.load(string)
     add_lc_filename(result, uri)
@@ -363,7 +347,7 @@ def load_inputfile_by_yaml(
     uri: str,
     loadingOptions: Optional[cwl.LoadingOptions] = None,
 ) -> Any:
-    """Load a CWL v1.1 input file from a YAML object."""
+    """Load a CWL v1.0 input file from a YAML object."""
     add_lc_filename(yaml, uri)
 
     if loadingOptions is None:
@@ -397,10 +381,7 @@ def type_for_step_input(
     cwl_utils.parser.utils.convert_stdstreams_to_files(step_run)
     if step_run and step_run.inputs:
         for step_input in step_run.inputs:
-            if (
-                cast(str, step_input.id).split("#")[-1]
-                == cast(str, in_.id).split("#")[-1]
-            ):
+            if cast(str, step_input.id).split("#")[-1] == in_.id.split("#")[-1]:
                 input_type = step_input.type_
                 if step.scatter is not None and in_.id in aslist(step.scatter):
                     input_type = cwl.ArraySchema(items=input_type, type_="array")
@@ -416,12 +397,12 @@ def type_for_step_output(
     step_run = cwl_utils.parser.utils.load_step(step)
     cwl_utils.parser.utils.convert_stdstreams_to_files(step_run)
     if step_run and step_run.outputs:
-        for output in step_run.outputs:
+        for step_output in step_run.outputs:
             if (
-                output.id.split("#")[-1].split("/")[-1]
+                step_output.id.split("#")[-1].split("/")[-1]
                 == sourcename.split("#")[-1].split("/")[-1]
             ):
-                output_type = output.type_
+                output_type = step_output.type_
                 if step.scatter is not None:
                     if step.scatterMethod == "nested_crossproduct":
                         for _ in range(len(aslist(step.scatter))):
@@ -496,11 +477,11 @@ def param_for_source_id(
     sourcenames: Union[str, list[str]],
     parent: Optional[cwl.Workflow] = None,
     scatter_context: Optional[list[Optional[tuple[int, str]]]] = None,
-) -> Union[list[cwl.WorkflowInputParameter], cwl.WorkflowInputParameter]:
+) -> Union[list[cwl.InputParameter], cwl.InputParameter]:
     """Find the process input parameter that matches one of the given sourcenames."""
     if isinstance(sourcenames, str):
         sourcenames = [sourcenames]
-    params: list[cwl.WorkflowInputParameter] = []
+    params: list[cwl.InputParameter] = []
     for sourcename in sourcenames:
         if not isinstance(process, cwl.Workflow):
             for param in process.inputs:
@@ -540,27 +521,26 @@ def param_for_source_id(
                                         ):
                                             params.append(output)
                                             if scatter_context is not None:
-                                                if scatter_context is not None:
-                                                    if isinstance(step.scatter, str):
-                                                        scatter_context.append(
-                                                            (
-                                                                1,
-                                                                step.scatterMethod
-                                                                or "dotproduct",
-                                                            )
+                                                if isinstance(step.scatter, str):
+                                                    scatter_context.append(
+                                                        (
+                                                            1,
+                                                            step.scatterMethod
+                                                            or "dotproduct",
                                                         )
-                                                    elif isinstance(
-                                                        step.scatter, MutableSequence
-                                                    ):
-                                                        scatter_context.append(
-                                                            (
-                                                                len(step.scatter),
-                                                                step.scatterMethod
-                                                                or "dotproduct",
-                                                            )
+                                                    )
+                                                elif isinstance(
+                                                    step.scatter, MutableSequence
+                                                ):
+                                                    scatter_context.append(
+                                                        (
+                                                            len(step.scatter),
+                                                            step.scatterMethod
+                                                            or "dotproduct",
                                                         )
-                                                    else:
-                                                        scatter_context.append(None)
+                                                    )
+                                                else:
+                                                    scatter_context.append(None)
     if len(params) == 1:
         return params[0]
     elif len(params) > 1:
